==> qtjambi-qt3dcore-6.2.8-sources.jar: io/qt/qt3d/core/QCoreSettings.java <==
package io.qt.qt3d.core;


/**
 * <p>Holds settings related to core data handling process</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3dcore-qcoresettings.html">Qt3DCore::QCoreSettings</a></p>
 */
public class QCoreSettings extends io.qt.qt3d.core.QComponent
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QCoreSettings.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dcore-qcoresettings.html#boundingVolumesEnabled-prop">Qt3DCore::QCoreSettings::boundingVolumesEnabledChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="boundingVolumesEnabled")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> boundingVolumesEnabledChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QCoreSettings(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QCoreSettings() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dcore-qcoresettings.html#QCoreSettings">Qt3DCore::QCoreSettings::QCoreSettings(Qt3DCore::QNode*)</a></p>
     */
    public QCoreSettings(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QCoreSettings instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dcore-qcoresettings.html#boundingVolumesEnabled-prop">Qt3DCore::QCoreSettings::boundingVolumesEnabled()const</a></p>
     */
    @io.qt.QtPropertyReader(name="boundingVolumesEnabled")
    @io.qt.QtUninvokable
    public final boolean boundingVolumesEnabled(){
        return boundingVolumesEnabled_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean boundingVolumesEnabled_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dcore-qcoresettings.html#boundingVolumesEnabled-prop">Qt3DCore::QCoreSettings::setBoundingVolumesEnabled(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="boundingVolumesEnabled")
    public final void setBoundingVolumesEnabled(boolean boundingVolumesEnabled){
        setBoundingVolumesEnabled_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), boundingVolumesEnabled);
    }
    
    private native void setBoundingVolumesEnabled_native_bool(long __this__nativeId, boolean boundingVolumesEnabled);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QCoreSettings(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QCoreSettings(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QCoreSettings instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3dcore-6.2.12-sources.jar: io/qt/qt3d/core/QCoreSettings.java <==
package io.qt.qt3d.core;

import io.qt.*;


/**
 * <p>Holds settings related to core data handling process</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3dcore-qcoresettings.html">Qt3DCore::QCoreSettings</a></p>
 */
public class QCoreSettings extends io.qt.qt3d.core.QComponent
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QCoreSettings.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dcore-qcoresettings.html#boundingVolumesEnabled-prop">Qt3DCore::QCoreSettings::boundingVolumesEnabledChanged(bool)</a></p>
     */
    @QtPropertyNotify(name="boundingVolumesEnabled")
    public final @NonNull Signal1<java.lang.@QtPrimitiveType@NonNull Boolean> boundingVolumesEnabledChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QCoreSettings() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dcore-qcoresettings.html#QCoreSettings">Qt3DCore::QCoreSettings::QCoreSettings(Qt3DCore::QNode*)</a></p>
     */
    public QCoreSettings(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QCoreSettings instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #boundingVolumesEnabled()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final boolean getBoundingVolumesEnabled() {
        return boundingVolumesEnabled();
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dcore-qcoresettings.html#boundingVolumesEnabled-prop">Qt3DCore::QCoreSettings::boundingVolumesEnabled()const</a></p>
     */
    @QtPropertyReader(name="boundingVolumesEnabled")
    @QtUninvokable
    public final boolean boundingVolumesEnabled(){
        return boundingVolumesEnabled_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean boundingVolumesEnabled_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dcore-qcoresettings.html#boundingVolumesEnabled-prop">Qt3DCore::QCoreSettings::setBoundingVolumesEnabled(bool)</a></p>
     */
    @QtPropertyWriter(name="boundingVolumesEnabled")
    public final void setBoundingVolumesEnabled(boolean boundingVolumesEnabled){
        setBoundingVolumesEnabled_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), boundingVolumesEnabled);
    }
    
    private native void setBoundingVolumesEnabled_native_bool(long __this__nativeId, boolean boundingVolumesEnabled);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QCoreSettings(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QCoreSettings(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QCoreSettings instance, QDeclarativeConstructor constructor);
    
}
